## Race Against Drift Diffusion (RADD) model
Contributors: [K. Dunovan](http://kdunovan.me), [J. Huang](http://www.github.com/jeremyahuang), & [T. Verstynen](http://www.cognitiveaxon.com)

This repository  contains code and documentation for fitting various inhibitory control and decision models to behavioral data and is associated with the following manuscripts:

* Dunovan, K., Lynch, B., Molesworth, T., & Verstynen, T. (2015). [Competing basal-ganglia pathways determine the difference between stopping and deciding not to go](http://www.elifesciences.org/content/4/e08723). Elife, 4, e08723.

* Dunovan, K., & Verstynen, T. (2017). [Errors in action timing and inhibition facilitate learning by tuning distinct mechanisms in the underlying decision process](https://www.biorxiv.org/content/early/2017/10/28/153676). bioRxiv, 153676.


### Install with pip
```sh
pip install --upgrade radd
```

### Interactive Demos:
Click the "launch binder" button below to open up an interactive demo of radd in your browser (created using [binder](http://mybinder.org/)). Or view/download the demo notebooks [here](https://nbviewer.jupyter.org/github/CoAxLab/radd).

[![Binder](http://mybinder.org/badge.svg)](http://mybinder.org:/repo/coaxlab/radd)
